/* ======================================================================== */
/* init.cpp                                                                 */
/*                                                                          */
/*		This file contains two subroutines: init_all() and init_block.      */
/*                                                                          */
/* init_all(void):                                                          */
/*		This subroutine initializes the various variables that store the    */
/* the energy and other properties of the boxes.  It sets all the values to */
/* zero and is only called once at the beginning of main().                 */
/*                                                                          */
/* init_block(int):                                                        */
/*		This subroutine resets the block accumulators (res[k]) for the      */
/* properties calculated at each time step.  It is used to generate many    */
/* different "block averages" values for statistical purposes.              */
/*                                                                          */
/* ======================================================================== */

#include "defines.h"

/* ************************************************************************ */
/*                                                                          */
/* ======================== Begin Subroutine ============================== */
/*                                                                          */
/* ************************************************************************ */
void init_all (void)
{

	/* ================================================================== */
	/*                                                                    */
	/* Initialize box variables.                                          */
	/*                                                                    */
	/* ================================================================== */
	for(int k=0; k<sim.NB; k++) {
		box[k].boxn	= 0;
		box[k].boxns	= 0;
		box[k].boxnres	= 0;
		box[k].temp	= 0.0;

		/* ================================================================== */
		/*                                                                    */
		/* Initialize en variables.                                           */
		/*                                                                    */
		/* ================================================================== */

		en[k].poten  = 0.0;
		en[k].potens = 0.0;
		en[k].nbond  = 0.0;
		en[k].nbonds = 0.0;
		en[k].bond   = 0.0;
		en[k].bend   = 0.0;
		en[k].tors   = 0.0;
		en[k].impr   = 0.0;
		en[k].coulomb= 0.0;


		/* ================================================================== */
		/*                                                                    */
		/* Initialize bp variables.                                           */
		/*                                                                    */
		/* ================================================================== */
		for(int i=0; i<sim.NC; i++) {
			bp[k][i].first = 0;
			bp[k][i].last  = 0;
			bp[k][i].nbox  = 0;
		}
	}// loop k ends


}// init_all ends


void init_param (void){
	for(int k=0; k<sim.NB; k++) {
		/* ----------------------------------------	*/
		/* Initialize phi and psi variable			*/
		/* ----------------------------------------	*/
		for(int i=0; i<torsN[k]; i++) {
			tors[k][i].phia  = 0.0;
			tors[k][i].phi	 = 0.0;
			tors[k][i].psia  = 0.0;
			tors[k][i].psi	 = 0.0;
			tors[k][i].thetaa= 0.0;
			tors[k][i].theta = 0.0;
			tors[k][i].count = 1;
		}
	}//end k loop

}

/* ************************************************************************ */
/*                                                                          */
/* ======================== Begin Subroutine ============================== */
/*                                                                          */
/* ************************************************************************ */

void init_block (int ibox)
{
	int k = ibox;

	for(int i=0; i<torsN[k]; i++) {
		tors[k][i].phia  = tors[k][i].phia/tors[k][i].count;
		tors[k][i].psia  = tors[k][i].psia/tors[k][i].count;
		tors[k][i].thetaa = tors[k][i].thetaa/tors[k][i].count;
		tors[k][i].count = 1;
	}

}
