/* ===================================================== */
/* read_sequence.c                                       */
/* This subroutine reads the desired DNA sequence in     */
/* from file.                                            */
/* ===================================================== */

#include "defines.h"
int calc_Nsalt(double);
void calc_bl(double);

void read_sequence(char *file_name, double salt_conc, double d_nc){
	FILE *fp;

	int size;

	fp = fopen(file_name,"r");

	/* Obtain the file size (including whitespace) */
	fseek (fp,0,SEEK_END);
	long file_size = ftell (fp);
	rewind (fp);

	/* Allocate memory according to file size */
	sequence.base = (char*)calloc(file_size+1,sizeof(char));
	if(sequence.base == NULL){fprintf(stdout, "ERROR: cannot allocate memory for sequence.base\n"); exit(11);}

	/* Loop through text, testing for whitespace and alpha (and discarding all other characters) */
	char C;
	while ((C=fgetc(fp)) != EOF){
		if (isspace(C) == 0 && isalpha(C) != 0){
			char bigC = toupper(C);
			if(bigC == 'A' || bigC == 'T' || bigC == 'C' || bigC == 'G')
			{
				sprintf(sequence.base, "%s%c", sequence.base, bigC);
				sequence.N = sequence.N + 1;
			}
		}
	}    

	size=strlen(sequence.base);

	if(size != sequence.N){fprintf(stdout,"The sequence number does not match the sequence!!\n"); exit(10);}

	/* Assign the beginning site and residue for each type of moleucule */
	natom_dna.tot = 3*sequence.N*2 - 2;

	natom_dna.dna1 = 0;
	natom_dna.dna2 = 3*sequence.N - 1;
	natom_dna.sod  = 6*sequence.N - 2 ;

	atom_dna = (struct atoms_dna*) calloc(natom_dna.tot,sizeof(struct atoms_dna));
	if(atom_dna == NULL){fprintf(stdout, "ERROR: cannot allocate memory for atom\n"); exit(11);}

}

