/* ===================================================== */
/* write_psf.c                                           */
/* This subroutine writes the bond, bend, and torsions   */
/* connectivity file.                                    */
/* ===================================================== */

#include "defines.h"

void write_psf(void){
	FILE *fp;
	int natoms = natom_dna.sod;

	int i;
	char psfname[256];
	sprintf(psfname, "%s.psf", fileprefix);
	fp = fopen(psfname,"w");

	fprintf(fp,"* Created by dna_energy. Thomas A. Knotts IV et al.\n*\n*\n*\n*\n\n");

	fprintf(fp,"%7d !NATOMS\n",natoms);

	for(i = 0; i<natoms/2; i++){
		fprintf(fp,"%8d ",i+1);
		fprintf(fp,"DNA1 ");
		fprintf(fp,"%-4d ",atom_dna[i].residue+1);
		fprintf(fp,"%s  ",atom_dna[i].res_name);
		fprintf(fp,"%-5s ",atom_dna[i].site_name);
		fprintf(fp,"%3d  ",atom_dna[i].site_id);
		fprintf(fp,"%13.6e   ",atom_dna[i].charge);
		fprintf(fp,"%07.3lf           0\n",atom_dna[i].mass);
	}

	for(i = natoms/2; i<natoms; i++){
		fprintf(fp,"%8d ",i+1);
		fprintf(fp,"DNA2 ");
		fprintf(fp,"%-4d ",atom_dna[i].residue+1);
		fprintf(fp,"%s  ",atom_dna[i].res_name);
		fprintf(fp,"%-5s ",atom_dna[i].site_name);
		fprintf(fp,"%3d  ",atom_dna[i].site_id);
		fprintf(fp,"%13.6e   ",atom_dna[i].charge);
		fprintf(fp,"%07.3lf           0\n",atom_dna[i].mass);
	}

	if(natoms!=natom_dna.tot) fprintf(fp,"%7d !NATOMS\n",natom_dna.tot-natom_dna.sod);

	for(i = natoms; i<natom_dna.tot; i++){
		fprintf(fp,"%8d ",i+1);
		fprintf(fp,"IONS ");
		fprintf(fp,"%-4d ",atom_dna[i].residue+1);
		fprintf(fp,"%s  ",atom_dna[i].res_name);
		fprintf(fp,"%-5s ",atom_dna[i].site_name);
		fprintf(fp,"%3d  ",atom_dna[i].site_id);
		fprintf(fp,"%13.6e   ",atom_dna[i].charge);
		fprintf(fp,"%07.3lf           0\n",atom_dna[i].mass);
	}

	fprintf(fp,"\n%8d !NBONDS\n",bondN_dna);
	for(i=0; i<bondN_dna; i++){
		fprintf(fp,"%8d%8d",bond_dna[i].a+1,bond_dna[i].b+1);
		if(i<bondN_dna-1){
			if((i+1)%4 == 0) fprintf(fp,"\n");
		}
		else fprintf(fp,"\n\n");
	}

	fprintf(fp,"%8d !NTHETA: angles\n",bendN_dna);
	for(i=0; i<bendN_dna; i++){
		fprintf(fp,"%8d%8d%8d",bend_dna[i].a+1,bend_dna[i].b+1,bend_dna[i].c+1);
		if(i<bendN_dna-1){
			if((i+1)%3 == 0) fprintf(fp,"\n");
		}
		else fprintf(fp,"\n\n");
	}
	fprintf(fp,"%8d !NPHI: dihedrals\n",torsN_dna);
	for(i=0; i<torsN_dna; i++){
		fprintf(fp,"%8d%8d%8d%8d",tors_dna[i].a+1,tors_dna[i].b+1,tors_dna[i].c+1,tors_dna[i].d+1);
		if(i<torsN_dna-1){
			if((i+1)%2 == 0) fprintf(fp,"\n");
		}
		else fprintf(fp,"\n\n");
	}

	fprintf(fp,"%8d !NIMPR\n\n",0);
	fprintf(fp,"%8d !HDON\n\n",0);
	fprintf(fp,"%8d !HACC\n\n",0);

	/* ============================================================ */
	/* Print the NNB, eight to a line.                              */
	/* ============================================================ */
	fprintf(fp,"%8d !NNB\n\n",0);
	for(i=0; i<natom_dna.tot; i++){
		if(i%8 == 0 && i!=0) fprintf(fp,"\n");
		fprintf(fp,"%8d",0);
	}
	fprintf(fp,"\n\n");

	fclose(fp);

}

