/* ===================================================== */
/* generate_dna_coordinates.c                            */
/* This generates the coordinates for the desired        */
/* sequence.                                             */
/* ===================================================== */

#include "defines.h"
void translate(void);

void generate_dna_coordinates(void){
	int i;
	int j = natom_dna.dna2-1;
	int k = natom_dna.dna2;
	double dtheta = 36.0 * PI / 180;
	double dz = 3.38;
	double theta_shift;
	double z_shift;
	int count = 0;
	/* Generate the 5' strand starting with the base of the 3' end */
	for(i=sequence.N-1; i>=0; i--){

		theta_shift = dtheta * (double)count;
		z_shift = dz * (double)count;

		/* Add the base */
		switch(sequence.base[i]){
			case 'A':
				atom_dna[j].x = AAA.r * cos((AAA.theta+theta_shift));
				atom_dna[j].y = AAA.r * sin((AAA.theta+theta_shift));
				atom_dna[j].z = AAA.z + z_shift;
				atom_dna[j].mass = AAA.mass;
				sprintf(atom_dna[j].site_name,"A");
				sprintf(atom_dna[j].res_name,"ADE");
				sprintf(atom_dna[j-1].res_name,"ADE");
				if(i != 0) sprintf(atom_dna[j-2].res_name,"ADE");
				//sprintf(atom[j-2].res_name,"ADE");
				atom_dna[j].residue = i;
				atom_dna[j].site_id = AAA.site_id;
				atom_dna[j].charge = AAA.charge;
				j = j - 1;
				break;
			case 'G':
				atom_dna[j].x = GGG.r * cos((GGG.theta+theta_shift));
				atom_dna[j].y = GGG.r * sin((GGG.theta+theta_shift));
				atom_dna[j].z = GGG.z + z_shift;
				atom_dna[j].mass = GGG.mass;
				sprintf(atom_dna[j].site_name,"G");
				sprintf(atom_dna[j].res_name,"GUA");
				sprintf(atom_dna[j-1].res_name,"GUA");
				atom_dna[j].residue = i;
				//sprintf(atom[j-2].res_name,"GUA");
				if(i != 0) sprintf(atom_dna[j-2].res_name,"GUA");
				atom_dna[j].site_id = GGG.site_id;
				atom_dna[j].charge = GGG.charge;
				j = j - 1;
				break;
			case 'T':
				atom_dna[j].x = TTT.r * cos((TTT.theta+theta_shift));
				atom_dna[j].y = TTT.r * sin((TTT.theta+theta_shift));
				atom_dna[j].z = TTT.z + z_shift;
				atom_dna[j].mass = TTT.mass;
				sprintf(atom_dna[j].site_name,"T");
				sprintf(atom_dna[j].res_name,"THY");
				sprintf(atom_dna[j-1].res_name,"THY");
				atom_dna[j].residue = i;
				//sprintf(atom[j-2].res_name,"THY");
				if(i != 0) sprintf(atom_dna[j-2].res_name,"THY");
				atom_dna[j].site_id = TTT.site_id;
				atom_dna[j].charge = TTT.charge;
				j = j - 1;
				break;
			case 'C':
				atom_dna[j].x = CCC.r * cos((CCC.theta+theta_shift));
				atom_dna[j].y = CCC.r * sin((CCC.theta+theta_shift));
				atom_dna[j].z = CCC.z + z_shift;
				atom_dna[j].mass = CCC.mass;
				sprintf(atom_dna[j].site_name,"C");
				sprintf(atom_dna[j].res_name,"CYT");
				sprintf(atom_dna[j-1].res_name,"CYT");
				atom_dna[j].residue = i;
				//sprintf(atom[j-2].res_name,"CYT");
				if(i != 0) sprintf(atom_dna[j-2].res_name,"CYT");
				atom_dna[j].site_id = CCC.site_id;
				atom_dna[j].charge = CCC.charge;
				j = j - 1;
				break;
		}

		/* Add the sugar */
		atom_dna[j].x = SSS.r * cos((SSS.theta+theta_shift));
		atom_dna[j].y = SSS.r * sin((SSS.theta+theta_shift));
		atom_dna[j].z = SSS.z + z_shift;
		atom_dna[j].mass = SSS.mass;
		sprintf(atom_dna[j].site_name,"S");
		atom_dna[j].residue = i;
		atom_dna[j].site_id = SSS.site_id;
		atom_dna[j].charge = SSS.charge;
		j = j - 1;

		/* Add the phosphate */
		if(i != 0){
			atom_dna[j].x = PPP.r * cos((PPP.theta+theta_shift));
			atom_dna[j].y = PPP.r * sin((PPP.theta+theta_shift));
			atom_dna[j].z = PPP.z + z_shift;
			atom_dna[j].mass = PPP.mass;
			sprintf(atom_dna[j].site_name,"P");
			atom_dna[j].residue = i;
			atom_dna[j].site_id = PPP.site_id;
			atom_dna[j].charge = PPP.charge;
			j = j - 1;
		}
		count = count + 1;
	}

	count = 0;
	/* Generate the 3' strand starting with the sugar of the 5' end */
	for(i=sequence.N-1; i>=0; i--){

		theta_shift = dtheta * (double)count;
		z_shift = dz * (double)count;

		/* Add the phosphate */
		if(i != sequence.N-1){
			atom_dna[k].x = PPP.r * cos((-PPP.theta+theta_shift));
			atom_dna[k].y = PPP.r * sin((-PPP.theta+theta_shift));
			atom_dna[k].z = -PPP.z + z_shift;
			atom_dna[k].mass = PPP.mass;
			sprintf(atom_dna[k].site_name,"P");
			atom_dna[k].residue = count + sequence.N;
			atom_dna[k].site_id = PPP.site_id;
			atom_dna[k].charge = PPP.charge;
			k = k + 1;
		}

		/* Add the sugar */
		atom_dna[k].x = SSS.r * cos((-SSS.theta+theta_shift));
		atom_dna[k].y = SSS.r * sin((-SSS.theta+theta_shift));
		atom_dna[k].z = -SSS.z + z_shift;
		atom_dna[k].mass = SSS.mass;
		sprintf(atom_dna[k].site_name,"S");
		atom_dna[k].residue = count + sequence.N;
		atom_dna[k].site_id = SSS.site_id;
		atom_dna[k].charge = SSS.charge;
		k = k + 1;

		switch(sequence.base[i]){
			case 'T':
				atom_dna[k].x = AAA.r * cos((-AAA.theta+theta_shift));
				atom_dna[k].y = AAA.r * sin((-AAA.theta+theta_shift));
				atom_dna[k].z = -AAA.z + z_shift;
				atom_dna[k].mass = AAA.mass;
				sprintf(atom_dna[k].site_name,"A");
				sprintf(atom_dna[k].res_name,"ADE");
				sprintf(atom_dna[k-1].res_name,"ADE");
				atom_dna[k].residue = count + sequence.N;
				//sprintf(atom[k-2].res_name,"ADE");
				if(i != sequence.N-1) sprintf(atom_dna[k-2].res_name,"ADE");
				atom_dna[k].site_id = AAA.site_id;
				atom_dna[k].charge = AAA.charge;
				k = k + 1;
				break;
			case 'C':
				atom_dna[k].x = GGG.r * cos((-GGG.theta+theta_shift));
				atom_dna[k].y = GGG.r * sin((-GGG.theta+theta_shift));
				atom_dna[k].z = -GGG.z + z_shift;
				atom_dna[k].mass = GGG.mass;
				sprintf(atom_dna[k].site_name,"G");
				sprintf(atom_dna[k].res_name,"GUA");
				sprintf(atom_dna[k-1].res_name,"GUA");
				atom_dna[k].residue = count + sequence.N;
				//	sprintf(atom[k-2].res_name,"GUA");
				if(i != sequence.N-1) sprintf(atom_dna[k-2].res_name,"GUA");
				atom_dna[k].site_id = GGG.site_id;
				atom_dna[k].charge = GGG.charge;
				k = k + 1;
				break;
			case 'A':
				atom_dna[k].x = TTT.r * cos((-TTT.theta+theta_shift));
				atom_dna[k].y = TTT.r * sin((-TTT.theta+theta_shift));
				atom_dna[k].z = -TTT.z + z_shift;
				atom_dna[k].mass = TTT.mass;
				sprintf(atom_dna[k].site_name,"T");
				sprintf(atom_dna[k].res_name,"THY");
				sprintf(atom_dna[k-1].res_name,"THY");
				atom_dna[k].residue = count + sequence.N;
				//sprintf(atom[k-2].res_name,"THY");
				if(i != sequence.N-1) sprintf(atom_dna[k-2].res_name,"THY");
				atom_dna[k].site_id = TTT.site_id;
				atom_dna[k].charge = TTT.charge;
				k = k + 1;
				break;
			case 'G':
				atom_dna[k].x = CCC.r * cos((-CCC.theta+theta_shift));
				atom_dna[k].y = CCC.r * sin((-CCC.theta+theta_shift));
				atom_dna[k].z = -CCC.z + z_shift;
				atom_dna[k].mass = CCC.mass;
				sprintf(atom_dna[k].site_name,"C");
				sprintf(atom_dna[k].res_name,"CYT");
				sprintf(atom_dna[k-1].res_name,"CYT");
				atom_dna[k].residue = count
					+ sequence.N;
				//sprintf(atom[k-2].res_name,"CYT");
				if(i != sequence.N-1) sprintf(atom_dna[k-2].res_name,"CYT");
				atom_dna[k].site_id = CCC.site_id;
				atom_dna[k].charge = CCC.charge;
				k = k + 1;
				break;
		}


		count = count + 1;

	}
	if (k != natom_dna.sod){printf("The number of DNA sites is not correct!\n"); exit(2);}
	translate();

}
